@@ -8,13 +8,13 @@ import pytest
 import narwhals as nw
 
 if TYPE_CHECKING:
-    from collections.abc import Sequence
+    from collections.abc import Iterable
 
 
 # https://github.com/narwhals-dev/narwhals/issues/1486
 @dataclass
 class Foo:
-    a: Sequence[int]
+    a: Iterable[float]
 
 
 def test_dataclass_pandas() -> None:
@@ -22,8 +22,8 @@ def test_dataclass_pandas() -> None:
     import pandas as pd
 
     # dry-run to check that none of these error
-    asdict(Foo(pd.Series([1, 2, 3])))  # type: ignore[arg-type]
-    asdict(Foo(nw.from_native(pd.Series([1, 2, 3]), series_only=True)))  # type: ignore[arg-type]
+    asdict(Foo(pd.Series([1, 2, 3])))
+    asdict(Foo(nw.from_native(pd.Series([1, 2, 3]), series_only=True)))
 
 
 def test_dataclass_polars() -> None:
@@ -31,5 +31,5 @@ def test_dataclass_polars() -> None:
     import polars as pl
 
     # dry-run to check that none of these error
-    asdict(Foo(pl.Series([1, 2, 3])))  # type: ignore[arg-type]
-    asdict(Foo(nw.from_native(pl.Series([1, 2, 3]), series_only=True)))  # type: ignore[arg-type]
+    asdict(Foo(pl.Series([1, 2, 3])))
+    asdict(Foo(nw.from_native(pl.Series([1, 2, 3]), series_only=True)))
