@@ -1,17 +1,17 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Callable
 
 import pytest
 
 import narwhals as nw
 
 if TYPE_CHECKING:
-    from tests.utils import Constructor
+    import pandas as pd
 
 
 def test_ops_preserve_column_index_name(
-    constructor: Constructor, request: pytest.FixtureRequest
+    constructor: Callable[..., pd.DataFrame], request: pytest.FixtureRequest
 ) -> None:
     if not any(x in str(constructor) for x in ("pandas", "modin", "cudf", "dask")):
         pytest.skip(
@@ -23,11 +23,11 @@ def test_ops_preserve_column_index_name(
 
     data = {"a": [1, 3, 2], "b": [4, 4, 6], "z": [7.0, 8.0, 9.0]}
     df_native = constructor(data)
-    df_native.columns.name = "foo"  # type: ignore[union-attr]
+    df_native.columns.name = "foo"
 
     df = nw.from_native(df_native)
 
     result = df.with_columns(b=nw.col("a") + 1, c=nw.col("a") * 2).select("c", "b")
 
-    assert result.to_native().columns.name == "foo"  # type: ignore[union-attr]
+    assert result.to_native().columns.name == "foo"
     assert result.lazy().collect(backend="pandas").to_native().columns.name == "foo"
